/********************************************************************
* global.h                                                          *
*                                                                   *
* Description:                                                      *
*   Symbols and variables for use in all program files              *
*                                                                   *
* Modification Record:                                              *
*                                                                   *
********************************************************************/
#ifndef GLOBAL_H
#define GLOBAL_H

/************************* Global Symbols **************************/
/* Just in case... */
#ifndef TRUE
#define TRUE 1
#endif
#ifndef FALSE
#define FALSE 0
#endif

/* Symbols for controls.  As such (reports that a control has
 * changed), these are also the return values from process_ctlpanel(),
 * not just "control" indices. */
enum PARPORT_CONTROL {
    WIN_SW1_STATE,       /* Toggle state for Switch 1 */
    WIN_SW1_MODE,        /* Mode for Switch 1 */
    WIN_SW2_STATE,       /* Toggle state for Switch 2 */
    WIN_SW2_MODE,        /* Mode for Switch 2 */
    WIN_LED1_MODE,       /* Mode for Single LED 1 */
    WIN_LED2_MODE,       /* Mode for Single LED 2 */
    WIN_ROTENC_COUNT,    /* Count for Rotary Encoder */
    WIN_ROTENC_RESET,    /* Control to clear Rotary Encoder count */
    WIN_ROTENC_ULIMIT,   /* Rotary Encoder count upper limit */
    WIN_ROTENC_LLIMIT,   /* Rotary Encoder count lower limit */
    WIN_ROTENC_BASE,     /* Counting Base for Rotary Encoder */
    WIN_ROTENC_MODE,     /* Mode for Rotary Encoder */
    WIN_7SEG_VALUE,      /* Value for Seven-Segment Display */
    WIN_7SEG_BASE,       /* Counting Base for Seven-Segment Display */
    WIN_7SEG_MODE,       /* Mode for Seven-Segment Display */
    MAX_PARPORT_CONTROL, /* End of Controls list */
    /* process_ctlpanel return values */
    CTLPANEL_TERMINATE,  /* End program */
    CTLPANEL_NOACTION    /* No Action Requested */
};

enum CTL_SW1_MODE {
    SW1_NORMAL,           /* Do nothing special */
    SW1_TOGGLE_LED1,      /* Toggle state of LED1 */
    SW1_TOGGLE_7SEG,      /* Toggle mode of 7-seg display */
    SW1_DISABLE,          /* Ignore Switch 1 */
    MAX_SW1_MODE
};

enum CTL_SW2_MODE {
    SW2_NORMAL,           /* Do nothing special */
    SW2_TOGGLE_LED2,      /* Toggle state of LED2 */
    SW2_TOGGLE_DISPLAY,   /* Turn on/off all displays */
    SW2_TERMINATE,        /* Terminate the program */
    SW2_DISABLE,          /* Ignore Switch 2 */
    MAX_SW2_MODE
};

enum CTL_LED1_MODE {
    LED1_NORMAL,          /* Do nothing special */
    LED1_BLINK,           /* Blink on/off */
    LED1_RAMP,            /* "Soft" blink */
    LED1_ON,              /* LED always on (ignore other commands) */
    LED1_OFF,             /* LED always off (ignore other commands) */
    MAX_LED1_MODE
};

enum CTL_LED2_MODE {
    LED2_NORMAL,          /* Do nothing special */
    LED2_BLINK,           /* Blink on/off */
    LED2_RAMP,            /* "Soft" blink */
    LED2_ON,              /* LED always on (ignore other commands) */
    LED2_OFF,             /* LED always off (ignore other commands) */
    MAX_LED2_MODE
};

enum CTL_ROTENC_MODE {
    ROTENC_NORMAL,        /* Spin end-to-end */
    ROTENC_LIMIT,         /* Count is limited */
    ROTENC_DISABLE,       /* Ignore rotary encoder */
    MAX_ROTENC_MODE
};

enum CTL_SVNSEG_MODE {
    SVNSEG_TIMER,         /* Display increments in time */
    SVNSEG_ROTENC,        /* Display follows rotary encoder */
    SVNSEG_ON,            /* All segments on ("8"; "Lamp Test") */
    SVNSEG_OFF,           /* All segments off ("Blank") */
    MAX_SVNSEG_MODE
};

enum COUNT_BASE {
    DECIMAL,              /* Base-10 */
    HEXADECIMAL,          /* Base-16 */
    OCTAL,                /* Base-8 */
    MAX_COUNT_BASE
};

enum DISPLAY_CONDITION {
    DISPLAY_NORMAL,       /* Let displays work normally */
    DISPLAY_LAMP_TEST,    /* Displays always on */
    DISPLAY_BLANK,        /* Displays always off */
    MAX_DISPLAY_CONDITION
};

/************************ Global Constants *************************/
extern const int base_max[];      /* Maximum value for 2-digit display */
extern const int base_digit[];    /* Value of "10" in number base */

/************************ Global Variables *************************/
extern enum CTL_SW1_MODE mode_sw1;           /* Mode of Switch 1 */
extern enum CTL_SW2_MODE mode_sw2;           /* Mode of Switch 2 */
extern enum CTL_LED1_MODE mode_led1;         /* Mode of LED 1 */
extern enum CTL_LED2_MODE mode_led2;         /* Mode of LED 2 */
extern enum CTL_ROTENC_MODE mode_rotenc;     /* Mode of Rotary Encoder */
extern enum CTL_SVNSEG_MODE mode_7seg;       /* Mode of Seven-Seg Display */
extern int state_sw1;             /* State of Switch 1 (up/down) */
extern int toggle_sw1;            /* State toggled by Switch 1 (on/off) */
extern int enable_sw1;            /* TRUE to enable Switch 1 */
extern int state_sw2;             /* State of Switch 2 (up/down) */
extern int toggle_sw2;            /* State toggled by Switch 2 (on/off) */
extern int enable_sw2;            /* TRUE to enable Switch 2 */
extern int state_led1;            /* State of LED 1 (on/off) */
extern int on_led1;               /* TRUE to turn LED 1 on */
extern int state_led2;            /* State of LED 2 (on/off) */
extern int on_led2;               /* TRUE to turn LED 1 on */
extern int count_rotenc;          /* Count updated by Rotary Encoder */
extern int enable_rotenc;         /* TRUE to enable Rotary Encoder */
extern enum COUNT_BASE base_rotenc;   /* Counting base of Rotary Encoder */
extern int ulim_rotenc;           /* Upper limit for Rotary Encoder */
extern int llim_rotenc;           /* Lower limit for Rotary Encoder */
extern int display_7seg;          /* Value displayed by Seven-Seg Display */
extern enum COUNT_BASE base_7seg;   /* Counting base of Seven-Seg Display */
extern enum DISPLAY_CONDITION lamp_set;   /* Display override flag */

#endif /* #ifdef GLOBAL_H */

